/*
 *  (c) 2005,2006 Frank A. Zdarsky, disco | Distributed Computer Systems Lab
 *                                  University of Kaiserslautern, Germany
 *         All Rights Reserved.
 *
 *  This software is work in progress and is released in the hope that it will
 *  be useful to the scientific community. It is provided "as is" without
 *  express or implied warranty, including but not limited to the correctness
 *  of the code or its suitability for any particular purpose.
 *
 *  You are free to use this software for any non-commercial educational or
 *  research purpose, provided that this copyright notice is not removed or
 *  modified. For commercial uses please contact the respective author(s).
 *
 *  If you find our software useful, we would appreciate if you mentioned it
 *  in any publication arising from the use of this software or acknowledge
 *  our work otherwise. We would also like to hear of any fixes or useful
 *  extensions to this software.
 *
 */

package unikl.disco.math.functions;

/**
 * Interface for piecewise-linear functions.
 * 
 * @author Frank A. Zdarsky
 * @see Function
 */
public interface PWLFunction extends Function {
	/**
	 * Returns the number of line segments of which the piecewise-linear
	 * function consists.
	 * @return the number of segments
	 */
	public int getSegmentCount();
	
	/**
	 * The x-coordinate of the <code>i</code>-th inflection point.
	 * <code>i</code> needs to be in the range [0,<code>getSegmentCount()</code>).
	 *  
	 * @param i the index of the inflection point
	 * @return the x-coordinate of the inflection point
	 */
	public double getIPX(int i);
	
	/**
	 * The y-coordinate of the <code>i</code>-th inflection point.
	 * <code>i</code> needs to be in the range [0,<code>getSegmentCount()</code>).
	 *  
	 * @param i the index of the inflection point
	 * @return the y-coordinate of the inflection point
	 */
	public double getIPY(int i);
	
	/**
	 * Returns <code>true</code> if the <code>i</code>-th inflection point is
	 * in the definition interval of the segment and <code>false</code> if not.
	 *  
	 * @param i the index of the inflection point
	 * @return whether the inflection point is in the segment's definition interval
	 */
	public boolean isLeftopen(int i);
}
